@@ -24,12 +24,12 @@
 #define BYTEARRAYUUENCODINGSTREAMENCODERCONFIGEDITORFACTORY_H
 
 // lib
-#include "oktetakastengui_export.h"
-// Okteta gui
-#include <abstractmodelstreamencoderconfigeditorfactory.h>
+#include <kasten/okteta/oktetakastengui_export.h>
+// Kasten gui
+#include <kasten/abstractmodelstreamencoderconfigeditorfactory.h>
 
 
-namespace Kasten2
+namespace Kasten
 {
 
 class ByteArrayUuencodingStreamEncoderConfigEditorFactory : public AbstractModelStreamEncoderConfigEditorFactory
